@@ -2,26 +2,16 @@
 # dependencies = ["rich-click>=1.9", "typer>=0.15"]
 # ///
 
-# This example comes from the Typer docs:
+# This example is based on an example from the Typer docs,
+# but with some modifications to increase test coverage:
 # https://typer.tiangolo.com/tutorial/commands/help/#help-panels-for-commands
 import typer
+from typing_extensions import Annotated
 
 
 cli = typer.Typer(rich_markup_mode="rich", no_args_is_help=True)
 
 
-@cli.command()
-def create(username: str) -> None:
-    """[green]Create[/green] a new user. :sparkles:"""
-    print(f"Creating user: {username}")
-
-
-@cli.command()
-def delete(username: str) -> None:
-    """[red]Delete[/red] a user. :fire:"""
-    print(f"Deleting user: {username}")
-
-
 @cli.command(rich_help_panel="Utils and Configs")
 def config(configuration: str) -> None:
     """[blue]Configure[/blue] the system. :wrench:"""
@@ -46,5 +36,23 @@ def report() -> None:
     print("Please open a new issue online, not a direct message")
 
 
+@cli.command()
+def create(
+    username: str,
+    verbose: Annotated[bool, typer.Option(rich_help_panel="Logging")] = False,
+    debug: Annotated[bool, typer.Option(rich_help_panel="Logging")] = False,
+    force: Annotated[bool, typer.Option()] = False,
+) -> None:
+    """[green]Create[/green] a new user. :sparkles:"""
+    print(f"Config: verbose={verbose} debug={debug} force={force}")
+    print(f"Creating user: {username}")
+
+
+@cli.command()
+def delete(username: str) -> None:
+    """[red]Delete[/red] a user. :fire:"""
+    print(f"Deleting user: {username}")
+
+
 if __name__ == "__main__":
     cli()
